@@ -3,329 +3,276 @@
     <name>MainWindow</name>
     <message>
         <location filename="../src/mainwindow.ui" line="14"/>
-        <location filename="../src/ui_mainwindow.h" line="569"/>
         <source>Program_Name</source>
         <translation>Program_Name</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="46"/>
-        <location filename="../src/ui_mainwindow.h" line="571"/>
         <source>Quit application</source>
         <translation>Surt de l&apos;aplicació</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="49"/>
-        <location filename="../src/ui_mainwindow.h" line="573"/>
         <source>Close</source>
         <translation>Tanca</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="55"/>
-        <location filename="../src/ui_mainwindow.h" line="575"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="87"/>
-        <location filename="../src/ui_mainwindow.h" line="578"/>
         <source>Display help </source>
         <translation>Mostra l&apos;ajuda</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="90"/>
-        <location filename="../src/ui_mainwindow.h" line="580"/>
         <source>Help</source>
         <translation>Ajuda </translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="96"/>
-        <location filename="../src/ui_mainwindow.h" line="582"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="112"/>
-        <location filename="../src/ui_mainwindow.h" line="584"/>
         <source>Back</source>
         <translation>Enrere</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="169"/>
-        <location filename="../src/ui_mainwindow.h" line="586"/>
         <source>Next</source>
         <translation>Següent</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="194"/>
-        <location filename="../src/ui_mainwindow.h" line="591"/>
         <source>About this application</source>
         <translation>Quant a aquest programa</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="197"/>
-        <location filename="../src/ui_mainwindow.h" line="593"/>
         <source>About...</source>
         <translation>Quant a...</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="203"/>
-        <location filename="../src/ui_mainwindow.h" line="595"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.ui" line="219"/>
-        <location filename="../src/ui_mainwindow.h" line="597"/>
         <source>View Log</source>
         <translation>Veure el registre</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="253"/>
-        <location filename="../src/mainwindow.cpp" line="583"/>
-        <location filename="../src/mainwindow.cpp" line="606"/>
-        <location filename="../src/ui_mainwindow.h" line="598"/>
+        <location filename="../src/mainwindow.ui" line="745"/>
+        <location filename="../src/mainwindow.cpp" line="592"/>
+        <location filename="../src/mainwindow.cpp" line="615"/>
         <source>Select ISO</source>
         <translation>Trieu la ISO</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="263"/>
-        <location filename="../src/ui_mainwindow.h" line="599"/>
+        <location filename="../src/mainwindow.ui" line="541"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Trieu el dispositiu USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="273"/>
-        <location filename="../src/ui_mainwindow.h" line="600"/>
+        <location filename="../src/mainwindow.ui" line="247"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Trieu el fitxer ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="289"/>
-        <location filename="../src/ui_mainwindow.h" line="601"/>
+        <location filename="../src/mainwindow.ui" line="263"/>
         <source>Advanced Options</source>
         <translation>Opcions avançades</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="307"/>
-        <location filename="../src/ui_mainwindow.h" line="602"/>
+        <location filename="../src/mainwindow.ui" line="375"/>
         <source>Make the ext4 filesystem even if one exists</source>
         <translation>Crea un sistema de fitxers ext4 malgrat que n&apos;hi hagi un</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="314"/>
-        <location filename="../src/ui_mainwindow.h" line="603"/>
+        <location filename="../src/mainwindow.ui" line="382"/>
         <source>Save the original boot directory when updating a live-usb</source>
         <translation>Desa el directori d&apos;arrencada original quan s&apos;actualitza el USB autònom</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="321"/>
-        <location filename="../src/ui_mainwindow.h" line="605"/>
+        <location filename="../src/mainwindow.ui" line="389"/>
         <source>Use gpt partitioning instead of msdos</source>
         <translation>Usa el particionat GPT en comptes de MSDOS</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="324"/>
-        <location filename="../src/ui_mainwindow.h" line="607"/>
+        <location filename="../src/mainwindow.ui" line="392"/>
         <source>GPT partitioning</source>
         <translation>Particionat GPT</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="331"/>
-        <location filename="../src/ui_mainwindow.h" line="608"/>
+        <location filename="../src/mainwindow.ui" line="399"/>
         <source>Update (only update an existing live-usb)</source>
         <translation>Actualitza (només un USB autònom existent)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="338"/>
-        <location filename="../src/ui_mainwindow.h" line="610"/>
+        <location filename="../src/mainwindow.ui" line="406"/>
         <source>Don&apos;t replace syslinux files</source>
         <translation>No substitueixis els fitxers Syslinux</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="341"/>
-        <location filename="../src/ui_mainwindow.h" line="612"/>
+        <location filename="../src/mainwindow.ui" line="409"/>
         <source>Keep syslinux files</source>
         <translation>Mantín els fitxers Syslinux</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="348"/>
-        <location filename="../src/ui_mainwindow.h" line="613"/>
+        <location filename="../src/mainwindow.ui" line="416"/>
         <source>Ignore USB/removable check</source>
         <translation>Ignora la comprovació USB/extraïble</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="355"/>
-        <location filename="../src/ui_mainwindow.h" line="614"/>
+        <location filename="../src/mainwindow.ui" line="423"/>
         <source>Temporarily disable automounting</source>
         <translation>Desactiva temporalment l&apos;automuntatge</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="365"/>
-        <location filename="../src/ui_mainwindow.h" line="618"/>
+        <location filename="../src/mainwindow.ui" line="433"/>
         <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
         <translation>Activa l&apos;indicador pmbr_boot (no arrenca amb UEFI)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="372"/>
-        <location filename="../src/ui_mainwindow.h" line="619"/>
+        <location filename="../src/mainwindow.ui" line="440"/>
         <source>Don&apos;t use fuseiso to mount iso files</source>
         <translation>No useu fuseiso per muntar fitxers ISO</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="398"/>
-        <location filename="../src/ui_mainwindow.h" line="620"/>
+        <location filename="../src/mainwindow.ui" line="288"/>
         <source>Size of ESP (uefi) partition:</source>
         <translation>Mida de la partició ESP (uefi): </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="421"/>
-        <location filename="../src/ui_mainwindow.h" line="621"/>
+        <location filename="../src/mainwindow.ui" line="353"/>
         <source>Verbosity (less to more):</source>
         <translation>Verbositat (de menys a més)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="465"/>
-        <location filename="../src/ui_mainwindow.h" line="623"/>
+        <location filename="../src/mainwindow.ui" line="329"/>
         <source>vfat</source>
         <translation>VFAT</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="506"/>
-        <location filename="../src/ui_mainwindow.h" line="628"/>
+        <location filename="../src/mainwindow.ui" line="478"/>
         <source>Data partition format type</source>
         <translation>Tipus de format de la partició de dades</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="460"/>
-        <location filename="../src/ui_mainwindow.h" line="622"/>
+        <location filename="../src/mainwindow.ui" line="324"/>
         <source>exfat</source>
         <translation>EXFAT</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="470"/>
-        <location filename="../src/ui_mainwindow.h" line="624"/>
+        <location filename="../src/mainwindow.ui" line="334"/>
         <source>ext4</source>
         <translation>ext4</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="475"/>
-        <location filename="../src/ui_mainwindow.h" line="625"/>
+        <location filename="../src/mainwindow.ui" line="339"/>
         <source>ntfs</source>
         <translation>NTFS</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="499"/>
-        <location filename="../src/ui_mainwindow.h" line="627"/>
+        <location filename="../src/mainwindow.ui" line="281"/>
         <source>Make separate data partition (percent)</source>
         <translation>Fes particions de dades separades (percentatge)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="516"/>
-        <location filename="../src/ui_mainwindow.h" line="629"/>
+        <location filename="../src/mainwindow.ui" line="768"/>
         <source>Refresh drive list</source>
         <translation>Refresca la llista d&apos;unitats</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="529"/>
+        <location filename="../src/mainwindow.ui" line="755"/>
         <location filename="../src/mainwindow.cpp" line="552"/>
-        <location filename="../src/ui_mainwindow.h" line="630"/>
         <source>Show advanced options</source>
         <translation>Mostra les opcions avançades</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="548"/>
-        <location filename="../src/ui_mainwindow.h" line="631"/>
+        <location filename="../src/mainwindow.ui" line="787"/>
         <source>Mode</source>
         <translation>Mode</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="563"/>
-        <location filename="../src/ui_mainwindow.h" line="632"/>
+        <location filename="../src/mainwindow.ui" line="808"/>
         <source>Full-featured mode - writable Li&amp;veUSB</source>
         <translation>Mode amb totes les funcions - USB autònom escri&amp;vible</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="573"/>
-        <location filename="../src/ui_mainwindow.h" line="634"/>
+        <location filename="../src/mainwindow.ui" line="818"/>
         <source>Read-only, cannot be used with persistency</source>
         <translation>Només lectura, no es pot usar amb persistència</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="576"/>
-        <location filename="../src/ui_mainwindow.h" line="636"/>
+        <location filename="../src/mainwindow.ui" line="821"/>
         <source>Image &amp;mode - read-only LiveUSB (dd)</source>
         <translation>Mode i&amp;matge - USB autònom de només lectura (dd)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="589"/>
-        <location filename="../src/ui_mainwindow.h" line="637"/>
+        <location filename="../src/mainwindow.ui" line="840"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
         <translation>Per distribucions diferents d&apos;antiX/MX useu el mode d&apos;Imatge (dd)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="637"/>
-        <location filename="../src/ui_mainwindow.h" line="638"/>
+        <location filename="../src/mainwindow.ui" line="557"/>
         <source>Options</source>
         <translation>Opcions </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="675"/>
-        <location filename="../src/ui_mainwindow.h" line="639"/>
+        <location filename="../src/mainwindow.ui" line="607"/>
         <source>Percent of USB-device to use:</source>
         <translation>Percentatge del dispositiu USB a usar: </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="682"/>
-        <location filename="../src/ui_mainwindow.h" line="640"/>
+        <location filename="../src/mainwindow.ui" line="620"/>
         <source>Label ext partition:</source>
         <translation>Etiqueta de la partició ext: </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="730"/>
-        <location filename="../src/ui_mainwindow.h" line="642"/>
+        <location filename="../src/mainwindow.ui" line="642"/>
         <source>Don&apos;t run commands that affect the usb device</source>
         <translation>No executeu ordres que afectin el dispositiu USB</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="733"/>
-        <location filename="../src/ui_mainwindow.h" line="644"/>
+        <location filename="../src/mainwindow.ui" line="645"/>
         <source>Dry run (no change to system)</source>
         <translation>Executa en sec (sense canvis al sistema)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="740"/>
-        <location filename="../src/ui_mainwindow.h" line="646"/>
+        <location filename="../src/mainwindow.ui" line="652"/>
         <source>clone from a mounted live-usb or iso-file.</source>
         <translation>Clona des d&apos;un USB autònom muntat o un fitxer ISO.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="743"/>
-        <location filename="../src/ui_mainwindow.h" line="648"/>
+        <location filename="../src/mainwindow.ui" line="655"/>
         <source>Clone a mounted live system</source>
         <translation>Clona un sistema autònom muntat</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="750"/>
-        <location filename="../src/ui_mainwindow.h" line="650"/>
+        <location filename="../src/mainwindow.ui" line="662"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
         <translation>Disposa per arrencar des d&apos;una partició encriptada, us demanarà la contrasenya a la primera arrencada</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="753"/>
-        <location filename="../src/ui_mainwindow.h" line="652"/>
+        <location filename="../src/mainwindow.ui" line="665"/>
         <source>Encrypt</source>
         <translation>Encripta</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.ui" line="760"/>
-        <location filename="../src/ui_mainwindow.h" line="653"/>
+        <location filename="../src/mainwindow.ui" line="672"/>
         <source>Clone running live system</source>
         <translation>Clona un sistema autònom executant-se</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="398"/>
         <location filename="../src/mainwindow.cpp" line="537"/>
-        <location filename="../src/mainwindow.cpp" line="705"/>
+        <location filename="../src/mainwindow.cpp" line="714"/>
         <source>Failure</source>
         <translation>Fallada</translation>
     </message>
@@ -335,27 +282,27 @@
         <translation>La font i destinació estan al mateix dispositiu, si us plau torneu a triar.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="750"/>
+        <location filename="../src/mainwindow.cpp" line="759"/>
         <source>Source Error</source>
         <translation>Error d&apos;origen</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="751"/>
+        <location filename="../src/mainwindow.cpp" line="760"/>
         <source>Could not find the source linuxfs file.</source>
-        <translation>No trobo el fitxer d&apos;origen linuxfs.</translation>
+        <translation>No s&apos;ha pogut trobar el fitxer d&apos;origen linuxfs.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="772"/>
+        <location filename="../src/mainwindow.cpp" line="781"/>
         <source>Warning: The target device (%1) is smaller than the source (%2). The data might not fit. Do you want to continue?</source>
         <translation>Atenció: El dispositiu de destinació (%1) és més petit  que el d&apos;origen (%2). Potser no hi cabran les dades. Voleu continuar?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="775"/>
+        <location filename="../src/mainwindow.cpp" line="784"/>
         <source>Size Warning</source>
         <translation>Advertència de mida</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="783"/>
+        <location filename="../src/mainwindow.cpp" line="792"/>
         <source>The target device %1 is larger than %2 GB.
 
 This may indicate you have selected the wrong device.
@@ -363,10 +310,10 @@ Are you sure you want to proceed?</source>
         <translation>El dispositiu de destinació %1 té més de %2 GB.
 
 Això potser indica que heu triat un dispositiu equivocat.
-Esteu segurs que voleu continuar?</translation>
+Segur que voleu continuar?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="790"/>
+        <location filename="../src/mainwindow.cpp" line="799"/>
         <source>Large Target Device Warning</source>
         <translation>Advertència de mida massa gran a destinació</translation>
     </message>
@@ -464,7 +411,7 @@ Si us plau, espereu fins que el procés s&apos;hagi acabat</translation>
     </message>
     <message>
         <location filename="../src/mainwindow.cpp" line="528"/>
-        <location filename="../src/mainwindow.cpp" line="578"/>
+        <location filename="../src/mainwindow.cpp" line="587"/>
         <source>Select Source Directory</source>
         <translation>Trieu el directori font</translation>
     </message>
@@ -479,26 +426,26 @@ Si us plau, espereu fins que el procés s&apos;hagi acabat</translation>
         <translation>Amaga les opcions avançades</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="577"/>
-        <location filename="../src/mainwindow.cpp" line="596"/>
+        <location filename="../src/mainwindow.cpp" line="586"/>
+        <location filename="../src/mainwindow.cpp" line="605"/>
         <source>Select Source</source>
         <translation>Trieu l&apos;origen</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="582"/>
-        <location filename="../src/mainwindow.cpp" line="604"/>
+        <location filename="../src/mainwindow.cpp" line="591"/>
+        <location filename="../src/mainwindow.cpp" line="613"/>
         <source>Select ISO file</source>
         <translation>Trieu el fitxer ISO</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="598"/>
+        <location filename="../src/mainwindow.cpp" line="607"/>
         <source>clone</source>
         <translation>clona</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="665"/>
+        <location filename="../src/mainwindow.cpp" line="674"/>
         <source>Could not find a log file at: </source>
-        <translation>No puc trobar un fitxer de registre a:</translation>
+        <translation>No s&apos;ha pogut trobar un fitxer de registre a:</translation>
     </message>
 </context>
 <context>
